package sun.print;

import java.awt.image.RenderedImage;
import java.awt.image.BufferedImageOp;
import java.awt.image.ImageObserver;
import java.awt.image.WritableRaster;
import java.awt.image.IndexColorModel;
import java.awt.image.SampleModel;
import java.awt.image.DataBuffer;
import java.awt.image.ColorModel;
import sun.awt.image.SunWritableRaster;
import java.awt.image.SinglePixelPackedSampleModel;
import java.awt.image.DataBufferInt;
import java.awt.image.VolatileImage;
import sun.awt.image.ToolkitImage;
import java.awt.image.BufferedImage;
import java.awt.Image;
import java.awt.geom.PathIterator;
import sun.font.PhysicalFont;
import sun.font.Font2D;
import java.awt.font.TextAttribute;
import sun.font.CompositeFont;
import sun.font.FontUtilities;
import java.awt.font.GlyphVector;
import java.text.AttributedCharacterIterator;
import java.awt.font.FontRenderContext;
import java.awt.Font;
import java.awt.font.TextLayout;
import java.awt.Polygon;
import java.awt.geom.Line2D;
import java.awt.geom.Arc2D;
import java.awt.geom.Ellipse2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.Paint;
import java.awt.Color;
import java.awt.print.PrinterException;
import java.awt.geom.AffineTransform;
import java.awt.Shape;
import java.awt.geom.Rectangle2D;
import java.awt.print.PrinterJob;
import java.awt.Graphics2D;
import sun.font.Font2DHandle;
import java.util.Hashtable;
import java.lang.ref.SoftReference;
import java.awt.print.PageFormat;
import java.awt.print.Printable;

public abstract class PathGraphics extends ProxyGraphics2D
{
    private Printable mPainter;
    private PageFormat mPageFormat;
    private int mPageIndex;
    private boolean mCanRedraw;
    protected boolean printingGlyphVector;
    protected static SoftReference<Hashtable<Font2DHandle, Object>> fontMapRef;
    
    protected PathGraphics(Graphics2D graphics2D, PrinterJob printerJob, Printable mPainter, PageFormat mPageFormat, int mPageIndex, boolean mCanRedraw) {
        super(graphics2D, printerJob);
        this.mPainter = mPainter;
        this.mPageFormat = mPageFormat;
        this.mPageIndex = mPageIndex;
        this.mCanRedraw = mCanRedraw;
    }
    
    protected Printable getPrintable() {
        return this.mPainter;
    }
    
    protected PageFormat getPageFormat() {
        return this.mPageFormat;
    }
    
    protected int getPageIndex() {
        return this.mPageIndex;
    }
    
    public boolean canDoRedraws() {
        return this.mCanRedraw;
    }
    
    public abstract void redrawRegion(Rectangle2D p0, double p1, double p2, Shape p3, AffineTransform p4) throws PrinterException;
    
    @Override
    public void drawLine(int n, int n2, int n3, int n4) {
        Paint paint = this.getPaint();
        try {
            AffineTransform transform = this.getTransform();
            if (this.getClip() != null) {
                this.deviceClip(this.getClip().getPathIterator(transform));
            }
            this.deviceDrawLine(n, n2, n3, n4, (Color)paint);
        }
        catch (ClassCastException ex) {
            throw new IllegalArgumentException("Expected a Color instance");
        }
    }
    
    @Override
    public void drawRect(int n, int n2, int n3, int n4) {
        Paint paint = this.getPaint();
        try {
            AffineTransform transform = this.getTransform();
            if (this.getClip() != null) {
                this.deviceClip(this.getClip().getPathIterator(transform));
            }
            this.deviceFrameRect(n, n2, n3, n4, (Color)paint);
        }
        catch (ClassCastException ex) {
            throw new IllegalArgumentException("Expected a Color instance");
        }
    }
    
    @Override
    public void fillRect(int n, int n2, int n3, int n4) {
        Paint paint = this.getPaint();
        try {
            AffineTransform transform = this.getTransform();
            if (this.getClip() != null) {
                this.deviceClip(this.getClip().getPathIterator(transform));
            }
            this.deviceFillRect(n, n2, n3, n4, (Color)paint);
        }
        catch (ClassCastException ex) {
            throw new IllegalArgumentException("Expected a Color instance");
        }
    }
    
    @Override
    public void clearRect(int n, int n2, int n3, int n4) {
        this.fill(new Rectangle2D.Float((float)n, (float)n2, (float)n3, (float)n4), this.getBackground());
    }
    
    @Override
    public void drawRoundRect(int n, int n2, int n3, int n4, int n5, int n6) {
        this.draw(new RoundRectangle2D.Float((float)n, (float)n2, (float)n3, (float)n4, (float)n5, (float)n6));
    }
    
    @Override
    public void fillRoundRect(int n, int n2, int n3, int n4, int n5, int n6) {
        this.fill(new RoundRectangle2D.Float((float)n, (float)n2, (float)n3, (float)n4, (float)n5, (float)n6));
    }
    
    @Override
    public void drawOval(int n, int n2, int n3, int n4) {
        this.draw(new Ellipse2D.Float((float)n, (float)n2, (float)n3, (float)n4));
    }
    
    @Override
    public void fillOval(int n, int n2, int n3, int n4) {
        this.fill(new Ellipse2D.Float((float)n, (float)n2, (float)n3, (float)n4));
    }
    
    @Override
    public void drawArc(int n, int n2, int n3, int n4, int n5, int n6) {
        this.draw(new Arc2D.Float((float)n, (float)n2, (float)n3, (float)n4, (float)n5, (float)n6, 0));
    }
    
    @Override
    public void fillArc(int n, int n2, int n3, int n4, int n5, int n6) {
        this.fill(new Arc2D.Float((float)n, (float)n2, (float)n3, (float)n4, (float)n5, (float)n6, 2));
    }
    
    @Override
    public void drawPolyline(int[] array, int[] array2, int n) {
        if (n > 0) {
            float x1 = (float)array[0];
            float y1 = (float)array2[0];
            float x2;
            float y2;
            for (int i = 1; i < n; x1 = x2, y1 = y2, ++i) {
                x2 = (float)array[i];
                y2 = (float)array2[i];
                this.draw(new Line2D.Float(x1, y1, x2, y2));
            }
        }
    }
    
    @Override
    public void drawPolygon(int[] xpoints, int[] ypoints, int npoints) {
        this.draw(new Polygon(xpoints, ypoints, npoints));
    }
    
    @Override
    public void drawPolygon(Polygon polygon) {
        this.draw(polygon);
    }
    
    @Override
    public void fillPolygon(int[] xpoints, int[] ypoints, int npoints) {
        this.fill(new Polygon(xpoints, ypoints, npoints));
    }
    
    @Override
    public void fillPolygon(Polygon polygon) {
        this.fill(polygon);
    }
    
    @Override
    public void drawString(String s, int n, int n2) {
        this.drawString(s, (float)n, (float)n2);
    }
    
    @Override
    public void drawString(String string, float x, float y) {
        if (string.length() == 0) {
            return;
        }
        new TextLayout(string, this.getFont(), this.getFontRenderContext()).draw(this, x, y);
        return;
    }
    
    protected void drawString(String string, float n, float n2, Font font, FontRenderContext frc, float n3) {
        this.fill(new TextLayout(string, font, frc).getOutline(AffineTransform.getTranslateInstance((double)n, (double)n2)));
    }
    
    @Override
    public void drawString(AttributedCharacterIterator attributedCharacterIterator, int n, int n2) {
        this.drawString(attributedCharacterIterator, (float)n, (float)n2);
    }
    
    @Override
    public void drawString(AttributedCharacterIterator text, float x, float y) {
        if (text == null) {
            throw new NullPointerException("attributedcharacteriterator is null");
        }
        new TextLayout(text, this.getFontRenderContext()).draw(this, x, y);
        return;
    }
    
    @Override
    public void drawGlyphVector(GlyphVector glyphVector, float n, float n2) {
        if (this.printingGlyphVector) {
            assert !this.printingGlyphVector;
            this.fill(glyphVector.getOutline(n, n2));
            return;
        }
        else {
            try {
                this.printingGlyphVector = true;
                if (RasterPrinterJob.shapeTextProp || !this.printedSimpleGlyphVector(glyphVector, n, n2)) {
                    this.fill(glyphVector.getOutline(n, n2));
                }
            }
            finally {
                this.printingGlyphVector = false;
            }
            return;
        }
    }
    
    protected int platformFontCount(Font font, String s) {
        return 0;
    }
    
    protected boolean printGlyphVector(GlyphVector glyphVector, float n, float n2) {
        return false;
    }
    
    boolean printedSimpleGlyphVector(GlyphVector glyphVector, float n, float n2) {
        int layoutFlags = glyphVector.getLayoutFlags();
        if (layoutFlags != 0 && layoutFlags != 2) {
            return this.printGlyphVector(glyphVector, n, n2);
        }
        Font font = glyphVector.getFont();
        Font2D font2D = FontUtilities.getFont2D(font);
        if (font2D.handle.font2D != font2D) {
            return false;
        }
        Hashtable<Font2D, Object> referent;
        synchronized (PathGraphics.class) {
            referent = (Hashtable)PathGraphics.fontMapRef.get();
            if (referent == null) {
                referent = new Hashtable();
                PathGraphics.fontMapRef = new SoftReference(referent);
            }
        }
        int numGlyphs = glyphVector.getNumGlyphs();
        int[] glyphCodes = glyphVector.getGlyphCodes(0, numGlyphs, (int[])null);
        char[] glyphToCharMapForFont = null;
        char[][] value = (char[][])null;
        CompositeFont compositeFont = null;
        synchronized (referent) {
            if ((font2D instanceof CompositeFont)) {
                compositeFont = (CompositeFont)font2D;
                int numSlots = compositeFont.getNumSlots();
                value = (char[][])(char[][])referent.get(font2D.handle);
                if (value == null) {
                    value = new char[numSlots][];
                    referent.put(font2D.handle, value);
                }
                int i = 0;
                while (i < numGlyphs) {
                    int slot = glyphCodes[i] >>> 24;
                    if (slot >= numSlots) {
                        return false;
                    }
                    if (value[slot] == null) {
                        PhysicalFont slotFont = compositeFont.getSlotFont(slot);
                        char[] glyphToCharMapForFont2 = (char[])(char[])referent.get(slotFont.handle);
                        if (glyphToCharMapForFont2 == null) {
                            glyphToCharMapForFont2 = getGlyphToCharMapForFont(slotFont);
                        }
                        value[slot] = glyphToCharMapForFont2;
                    }
                    ++i;
                }
            }
            else {
                glyphToCharMapForFont = (char[])(char[])referent.get(font2D.handle);
                if (glyphToCharMapForFont == null) {
                    glyphToCharMapForFont = getGlyphToCharMapForFont(font2D);
                    referent.put(font2D.handle, glyphToCharMapForFont);
                }
            }
        }
        char[] array = new char[numGlyphs];
        if (compositeFont != null) {
            int k = 0;
            while (k < numGlyphs) {
                int n5 = glyphCodes[k];
                char[] array2 = value[n5 >>> 24];
                int n6 = n5 & 0xFFFFFF;
                if (array2 == null) {
                    return false;
                }
                int n7;
                if (n6 == 65535) {
                    n7 = '\n';
                }
                else {
                    if (n6 < 0 || n6 >= array2.length) {
                        return false;
                    }
                    n7 = array2[n6];
                }
                if (n7 != '\uffff') {
                    array[k] = n7;
                    ++k;
                }
                else {
                    return false;
                }
            }
        }
        else {
            int j = 0;
            while (j < numGlyphs) {
                int n3 = glyphCodes[j];
                int n4;
                if (n3 == 65535) {
                    n4 = '\n';
                }
                else {
                    if (n3 < 0 || n3 >= glyphToCharMapForFont.length) {
                        return false;
                    }
                    n4 = glyphToCharMapForFont[n3];
                }
                if (n4 != '\uffff') {
                    array[j] = n4;
                    ++j;
                }
                else {
                    return false;
                }
            }
        }
        FontRenderContext fontRenderContext = glyphVector.getFontRenderContext();
        GlyphVector glyphVector2 = font.createGlyphVector(fontRenderContext, array);
        if (glyphVector2.getNumGlyphs() != numGlyphs) {
            return this.printGlyphVector(glyphVector, n, n2);
        }
        int[] glyphCodes2 = glyphVector2.getGlyphCodes(0, numGlyphs, (int[])null);
        int l = 0;
        while (l < numGlyphs) {
            if (glyphCodes[l] != glyphCodes2[l]) {
                return this.printGlyphVector(glyphVector, n, n2);
            }
            ++l;
        }
        FontRenderContext fontRenderContext2 = this.getFontRenderContext();
        int equals = fontRenderContext.equals(fontRenderContext2);
        if (equals == 0 && fontRenderContext.usesFractionalMetrics() == fontRenderContext2.usesFractionalMetrics()) {
            AffineTransform transform = fontRenderContext.getTransform();
            AffineTransform transform2 = this.getTransform();
            double[] flatmatrix = new double[4];
            double[] flatmatrix2 = new double[4];
            transform.getMatrix(flatmatrix);
            transform2.getMatrix(flatmatrix2);
            equals = 1;
            int n8 = 0;
            while (n8 < 4) {
                if (flatmatrix[n8] != flatmatrix2[n8]) {
                    equals = 0;
                    break;
                }
                ++n8;
            }
        }
        String str = new String(array, 0, numGlyphs);
        int platformFontCount = this.platformFontCount(font, str);
        if (platformFontCount == 0) {
            return false;
        }
        float[] glyphPositions = glyphVector.getGlyphPositions(0, numGlyphs, (float[])null);
        int n9 = ((layoutFlags & 0x2) == 0x0 || this.samePositions(glyphVector2, glyphCodes2, glyphCodes, glyphPositions)) ? 1 : 0;
        float n10 = (float)glyphVector.getGlyphPosition(numGlyphs).getX();
        boolean n11 = false;
        if (font.hasLayoutAttributes() && this.printingGlyphVector && n9 != 0) {
            Object value2 = font.getAttributes().get(TextAttribute.TRACKING);
            if (value2 != null && value2 instanceof Number && ((Number)value2).floatValue() != 0.0f) {
                n9 = 0;
            }
            else if ((double)Math.abs((float)font.getStringBounds(str, fontRenderContext).getWidth() - n10) > 1.0E-5) {
                n11 = true;
            }
        }
        if (equals != 0 && n9 != 0 && n11 == 0) {
            this.drawString(str, n, n2, font, fontRenderContext, 0.0f);
            return true;
        }
        if (platformFontCount == 1 && this.canDrawStringToWidth() && n9 != 0) {
            this.drawString(str, n, n2, font, fontRenderContext, n10);
            return true;
        }
        if (FontUtilities.isComplexText(array, 0, array.length)) {
            return this.printGlyphVector(glyphVector, n, n2);
        }
        if (numGlyphs > 10 && this.printGlyphVector(glyphVector, n, n2)) {
            return true;
        }
        for (int offset = 0; offset < numGlyphs; ++offset) {
            this.drawString(new String(array, offset, 1), n + glyphPositions[offset * 2], n2 + glyphPositions[offset * 2 + 1], font, fontRenderContext, 0.0f);
        }
        return true;
    }
    
    private boolean samePositions(GlyphVector glyphVector, int[] array, int[] array2, float[] array3) {
        int numGlyphs = glyphVector.getNumGlyphs();
        float[] glyphPositions = glyphVector.getGlyphPositions(0, numGlyphs, (float[])null);
        if (numGlyphs != array.length || array2.length != array.length || array3.length != glyphPositions.length) {
            return false;
        }
        int i = 0;
        while (i < numGlyphs) {
            if (array[i] != array2[i] || glyphPositions[i] != array3[i]) {
                return false;
            }
            ++i;
        }
        return true;
    }
    
    protected boolean canDrawStringToWidth() {
        return false;
    }
    
    private static char[] getGlyphToCharMapForFont(Font2D font2D) {
        int numGlyphs = font2D.getNumGlyphs();
        int missingGlyphCode = font2D.getMissingGlyphCode();
        char[] array = new char[numGlyphs];
        for (int i = 0; i < numGlyphs; ++i) {
            array[i] = '\uffff';
        }
        for (int j = '\0'; j < '\uffff'; j = (char)(j + 1)) {
            if (j < '?' || j > '?') {
                int charToGlyph = font2D.charToGlyph(j);
                if (charToGlyph != missingGlyphCode && charToGlyph >= 0 && charToGlyph < numGlyphs && array[charToGlyph] == '\uffff') {
                    array[charToGlyph] = j;
                }
            }
        }
        return array;
    }
    
    @Override
    public void draw(Shape shape) {
        this.fill(this.getStroke().createStrokedShape(shape));
    }
    
    @Override
    public void fill(Shape shape) {
        Paint paint = this.getPaint();
        try {
            this.fill(shape, (Color)paint);
        }
        catch (ClassCastException ex) {
            throw new IllegalArgumentException("Expected a Color instance");
        }
    }
    
    public void fill(Shape shape, Color color) {
        AffineTransform transform = this.getTransform();
        if (this.getClip() != null) {
            this.deviceClip(this.getClip().getPathIterator(transform));
        }
        this.deviceFill(shape.getPathIterator(transform), color);
    }
    
    protected abstract void deviceFill(PathIterator p0, Color p1);
    
    protected abstract void deviceClip(PathIterator p0);
    
    protected abstract void deviceFrameRect(int p0, int p1, int p2, int p3, Color p4);
    
    protected abstract void deviceDrawLine(int p0, int p1, int p2, int p3, Color p4);
    
    protected abstract void deviceFillRect(int p0, int p1, int p2, int p3, Color p4);
    
    protected BufferedImage getBufferedImage(Image image) {
        if ((image instanceof BufferedImage)) {
            return (BufferedImage)image;
        }
        if ((image instanceof ToolkitImage)) {
            return ((ToolkitImage)image).getBufferedImage();
        }
        if ((image instanceof VolatileImage)) {
            return ((VolatileImage)image).getSnapshot();
        }
        return null;
    }
    
    protected boolean hasTransparentPixels(BufferedImage bufferedImage) {
        ColorModel colorModel = bufferedImage.getColorModel();
        int n = colorModel == null || colorModel.getTransparency() != 1;
        if (n && bufferedImage != null && (bufferedImage.getType() == 2 || bufferedImage.getType() == 3)) {
            DataBuffer dataBuffer = bufferedImage.getRaster().getDataBuffer();
            SampleModel sampleModel = bufferedImage.getRaster().getSampleModel();
            if (dataBuffer instanceof DataBufferInt && sampleModel instanceof SinglePixelPackedSampleModel) {
                SinglePixelPackedSampleModel singlePixelPackedSampleModel = (SinglePixelPackedSampleModel)sampleModel;
                int[] stealData = SunWritableRaster.stealData((DataBufferInt)dataBuffer, 0);
                int i = bufferedImage.getMinX();
                int j = bufferedImage.getMinY();
                int width = bufferedImage.getWidth();
                int height = bufferedImage.getHeight();
                int scanlineStride = singlePixelPackedSampleModel.getScanlineStride();
                boolean n2 = false;
                while (j < j + height) {
                    int n3 = j * scanlineStride;
                    while (i < i + width) {
                        if ((stealData[n3 + i] & 0xFF000000) != 0xFF000000) {
                            n2 = true;
                            break;
                        }
                        ++i;
                    }
                    if (!(n2 == 0)) {
                        break;
                    }
                    ++j;
                }
                if (n2 == 0) {
                    n = false;
                }
            }
        }
        return n;
    }
    
    protected boolean isBitmaskTransparency(BufferedImage bufferedImage) {
        ColorModel colorModel = bufferedImage.getColorModel();
        return colorModel != null && colorModel.getTransparency() == 2;
    }
    
    protected boolean drawBitmaskImage(BufferedImage bufferedImage, AffineTransform affineTransform, Color color, int i, int j, int n, int n2) {
        ColorModel colorModel = bufferedImage.getColorModel();
        if (!(colorModel instanceof IndexColorModel)) {
            return false;
        }
        IndexColorModel indexColorModel = (IndexColorModel)colorModel;
        if (colorModel.getTransparency() != 2) {
            return false;
        }
        if (color != null && color.getAlpha() < 128) {
            return false;
        }
        if ((affineTransform.getType() & 0xFFFFFFF4) != 0x0) {
            return false;
        }
        if ((this.getTransform().getType() & 0xFFFFFFF4) != 0x0) {
            return false;
        }
        WritableRaster raster = bufferedImage.getRaster();
        int transparentPixel = indexColorModel.getTransparentPixel();
        byte[] a = new byte[indexColorModel.getMapSize()];
        indexColorModel.getAlphas(a);
        if (transparentPixel >= 0) {
            a[transparentPixel] = 0;
        }
        int width = raster.getWidth();
        int height = raster.getHeight();
        if (i > width || j > height) {
            return false;
        }
        int w;
        if (i + n > width) {
            w = width - i;
        }
        else {
            width = i + n;
            w = n;
        }
        if (j + n2 > height) {
        }
        else {
            height = j + n2;
        }
        int[] iArray = new int[w];
        int n3;
        BufferedImage subimage;
        BufferedImage subimage2;
        for (; j < height; ++j) {
            n3 = -1;
            raster.getPixels(i, j, w, 1, iArray);
            for (; i < width; ++i) {
                if (a[iArray[i - i]] == 0) {
                    if (n3 >= 0) {
                        subimage = bufferedImage.getSubimage(n3, j, i - n3, 1);
                        affineTransform.translate((double)n3, (double)j);
                        this.drawImageToPlatform(subimage, affineTransform, color, 0, 0, i - n3, 1, true);
                        affineTransform.translate((double)(-n3), (double)(-j));
                        n3 = -1;
                    }
                }
                else if (n3 < 0) {
                    n3 = i;
                }
            }
            if (n3 >= 0) {
                subimage2 = bufferedImage.getSubimage(n3, j, width - n3, 1);
                affineTransform.translate((double)n3, (double)j);
                this.drawImageToPlatform(subimage2, affineTransform, color, 0, 0, width - n3, 1, true);
                affineTransform.translate((double)(-n3), (double)(-j));
            }
        }
        return true;
    }
    
    protected abstract boolean drawImageToPlatform(Image p0, AffineTransform p1, Color p2, int p3, int p4, int p5, int p6, boolean p7);
    
    @Override
    public boolean drawImage(Image image, int n, int n2, ImageObserver imageObserver) {
        return this.drawImage(image, n, n2, null, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, int n3, int n4, ImageObserver imageObserver) {
        return this.drawImage(image, n, n2, n3, n4, null, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, Color color, ImageObserver imageObserver) {
        if (image == null) {
            return true;
        }
        int width = image.getWidth(null);
        int height = image.getHeight(null);
        return width >= 0 && height >= 0 && this.drawImage(image, n, n2, width, height, color, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, int n3, int n4, Color color, ImageObserver imageObserver) {
        if (image == null) {
            return true;
        }
        int width = image.getWidth(null);
        int height = image.getHeight(null);
        return width >= 0 && height >= 0 && this.drawImage(image, n, n2, n + n3, n2 + n4, 0, 0, width, height, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, int n3, int n4, int n5, int n6, int n7, int n8, ImageObserver imageObserver) {
        return this.drawImage(image, n, n2, n3, n4, n5, n6, n7, n8, null, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, int n3, int n4, int n5, int n6, int n7, int n8, Color color, ImageObserver imageObserver) {
        if (image == null) {
            return true;
        }
        int width = image.getWidth(null);
        int height = image.getHeight(null);
        if (width < 0 || height < 0) {
            return true;
        }
        int n9 = n7 - n5;
        int n10 = n8 - n6;
        float m00 = (float)(n3 - n) / (float)n9;
        float m2 = (float)(n4 - n2) / (float)n10;
        AffineTransform affineTransform = new AffineTransform(m00, 0.0f, 0.0f, m2, (float)n - (float)n5 * m00, (float)n2 - (float)n6 * m2);
        if (n7 < n5) {
            n5 = (n7 = n7);
        }
        if (n8 < n6) {
            n6 = (n8 = n8);
        }
        if (n5 < 0) {
            n5 = 0;
        }
        else if (n5 > width) {
            n5 = width;
        }
        if (n7 < 0) {
            n7 = 0;
        }
        else if (n7 > width) {
            n7 = width;
        }
        if (n6 < 0) {
            n6 = 0;
        }
        else if (n6 > height) {
            n6 = height;
        }
        if (n8 < 0) {
            n8 = 0;
        }
        else if (n8 > height) {
            n8 = height;
        }
        int n11 = n7 - n5;
        int n12 = n8 - n6;
        return n11 <= 0 || n12 <= 0 || this.drawImageToPlatform(image, affineTransform, color, n5, n6, n11, n12, false);
    }
    
    @Override
    public boolean drawImage(Image image, AffineTransform affineTransform, ImageObserver imageObserver) {
        if (image == null) {
            return true;
        }
        int width = image.getWidth(null);
        int height = image.getHeight(null);
        return width >= 0 && height >= 0 && this.drawImageToPlatform(image, affineTransform, null, 0, 0, width, height, false);
    }
    
    @Override
    public void drawImage(BufferedImage filter, BufferedImageOp bufferedImageOp, int n, int n2) {
        if (filter == null) {
            return;
        }
        int width = filter.getWidth(null);
        int height = filter.getHeight(null);
        if (bufferedImageOp != null) {
            filter = bufferedImageOp.filter(filter, null);
        }
        if (width <= 0 || height <= 0) {
            return;
        }
        this.drawImageToPlatform(filter, new AffineTransform(1.0f, 0.0f, 0.0f, 1.0f, (float)n, (float)n2), null, 0, 0, width, height, false);
        return;
    }
    
    @Override
    public void drawRenderedImage(RenderedImage renderedImage, AffineTransform affineTransform) {
        if (renderedImage == null) {
            return;
        }
        int width = renderedImage.getWidth();
        int height = renderedImage.getHeight();
        if (width <= 0 || height <= 0) {
            return;
        }
        BufferedImage bufferedImage;
        if ((renderedImage instanceof BufferedImage)) {
            bufferedImage = (BufferedImage)renderedImage;
        }
        else {
            bufferedImage = new BufferedImage(width, height, 2);
            bufferedImage.createGraphics().drawRenderedImage(renderedImage, affineTransform);
        }
        this.drawImageToPlatform(bufferedImage, affineTransform, null, 0, 0, width, height, false);
        return;
    }
    
    static {
        PathGraphics.fontMapRef = new SoftReference(null);
    }
}
